primap2.pm2io module
====================

.. _ref.primap2io:


The io module contains functions to read data from different formats and convert
it into the interchange format and the native primap2 format.

.. automodule:: primap2.pm2io
   :members:
   :undoc-members:
   :show-inheritance:
